@@ -18,7 +18,6 @@ import sys
 import json
 import time
 import platform
-#import datetime
 import hashlib
 import sqlite3
 
@@ -26,61 +25,84 @@ from . import s_log , s_config , s_util
 
 #####################################################################
 
-filepath = False
-db_con = False
+def setup( ) :
+    s_log.write( "setup" )
+    filedir_create( )
 
 #####################################################################
 
-def commitclose( ) :
-    
-    global db_con
+def filedir_create( ) :
+    os.makedirs( filedir_get( ) , exist_ok = True )
 
-    if( db_con != False ) :
-        db_con.commit( )
-        db_con.close( )
-        db_con = False 
+def filedir_get( ) :
+    dbworkspacedir = os.path.join( s_config.get_key( "sys/workspacedir" , "/tmp/sapiadapter" ) + "/db" , "" )
+    return( dbworkspacedir )
 
-def setup( ) :
+#####################################################################
 
-    global filepath
+def filepath_get( ) :
+    tid = str( s_util.thread_get_id( ) )
+    fn = s_config.get_key( "/config/session" ) + "-" + tid + ".db"
+    #s_log.write(fn)
+    fp = filedir_get( ) + fn
+    if not os.path.isfile( fp ) :
+        dbcon = sqlite3.connect( fp )
+        dbcon.commit( )
+        dbcon.close( )
+        init_schema()
+        init_data( )
+    return( fp )
 
-    #s_log.write(sys.argv)
-    #if(len(sys.argv)==3 and sys.argv[0]=="_sapi.py"):
-    #    filepath=sys.argv[1]
-    #    db_con_setup( )
-    #    s_log.write("db filepath " + filepath)
-    #    return
+def filepath_delete( ) :
+    fp = filepath_get( )
+    if os.path.isfile( fp ) :
+        os.remove( fp )
 
-    ################################################################
+def filepath_delete_all( ) :
+    for f in os.scandir(filedir_get()):
+        os.remove(f.path)
 
-    if( filepath != False ) :
-        flush( )
-        return( True )
+#####################################################################
 
-    s_log.write( "db setup" )
+def sql_execute( sql , params_tuple = False ) :
 
-    ################################################################
+    #s_log.write( sql )
 
-    filepath_setup( )
+    dbcon = sqlite3.connect( filepath_get( ) )
+    cur = dbcon.cursor( )
+    if params_tuple==False:
+        cur.execute( sql )
+    else:
+        cur.execute( sql , params_tuple )
+    dbcon.commit( )
+    dbcon.close( )
+    cur = False
+    dbcon = False
 
-    ################################################################
+def sql_execute_fetch( sql , fetch_all=False) :
 
-    db_con_setup( )
+    #s_log.write( sql )
 
-    ################################################################
+    dbcon = sqlite3.connect( filepath_get( ) )
+    dbcon.row_factory = lambda C , R : { c[ 0 ] : R[ i ] for i , c in enumerate( C.description ) }
+    cur = dbcon.cursor( )
+    cur.execute( sql )
 
-    if( not os.path.isfile( filepath ) ) :
-        s_log.write( "False filepath isfile" ) 
-        return( False )
+    if fetch_all : 
+        rows = cur.fetchall( )
+        dbcon.close( )
+        cur = False
+        dbcon = False
+        return( rows )
+    else :
+        row = cur.fetchone( )
+        dbcon.close( )
+        cur = False
+        dbcon = False
+        if( not row ) : return( False )
+        return( row )
 
-    ################################################################
-
-    init_schema( )
-    init_data( )
-    
-    ################################################################
-
-    return( True )
+#####################################################################
 
 def flush( ) :
 
@@ -92,7 +114,6 @@ def flush( ) :
     table_truncate( "meta" ) 
     table_truncate( "templates" ) 
 
-
 def init_data( ) :
 # FIXME TODO add host environment vars e.g. hostname/machine id etc.
     sys_create( "ver_db" , "1.0" )
@@ -112,25 +133,17 @@ def init_data( ) :
 
     #s_log.write(sys_read("time_isoformat"))
 
-def fdelete( ) :
-
-    commitclose( )
-
-    if( os.path.isfile( filepath ) ) :
-        os.remove( filepath )
-
 def file_contents( ) :
 
-    commitclose( )
 
-    if not os.path.isfile( filepath ) :
-        s_log.write( filepath + " NOT exists!" )
+    dbfp = filepath_get( )
+    if not os.path.isfile( dbfp ) :
+        s_log.write( dbfp + " NOT exists!" )
         return( False )
 
-    with open( filepath , mode = "rb" ) as file : 
+    with open( dbfp , mode = "rb" ) as file : 
         db_filecontents = file.read( )
 
-    db_con_setup( )
 
     return( db_filecontents )
 
@@ -146,19 +159,14 @@ def blob_get( ) :
 
 def rewrite( payload ) :
 
-    #rev = 1
-    #if( db_con_check( ) ) :
-    #    rev = sys_read( "rev" ) + 1
-
-    commitclose( )
-
     if( len( payload ) == 0 ) :
         s_log.write( "ERROR payload empty??")
 
-    with open( filepath , "wb" ) as file:
+    # FIXME TODO technically only the filepath is required - no need to create and init db file
+    dbfp = filepath_get( )
+    with open( dbfp , "wb" ) as file:
         file.write( payload )
 
-    db_con_setup( )
 
     ################################################################
 
@@ -169,81 +177,11 @@ def rewrite( payload ) :
         #s_log.write( "WARNING,VER_SAPI MISMATCH," + ver_sapi + "!=" + s_config.get_key( "/config/version" ) + "," + ver_db )
         s_log.write( "WARNING, VERSION MISMATCH," )
 
-
-    #sys_update("rev",rev)
-    #s_log.write("REV rewrite "+str(rev))
-
-def db_con_setup( ) :
-
-    global db_con
-
-    if( db_con != False ) : return
-
-    db_con = sqlite3.connect( filepath )
-    #db_con.row_factory = sqlite3.Row
-    db_con.row_factory = lambda C , R : { c[ 0 ] : R[ i ] for i , c in enumerate( C.description ) }
-
-    #s_log.write( "OK db_con_setup" )
-
-def db_con_check( ) :
-    global db_con
-    try :
-        db_con.cursor( )
-        return( True )
-    except Exception as ex :
-        return( False )
-
 #####################################################################
 
-
-def filepath_get( ) :
-    return( filepath )
-
-def filepath_setup( ) :
-
-    global filepath
-
-    if( filepath != False ) :
-        return
-
-    ################################################################
-
-    dbworkspacedir = os.path.join( s_config.get_key( "sys/workspacedir" , "/tmp/sapiadapter" ) + "/db" , "" )
-
-    os.makedirs( dbworkspacedir , exist_ok = True )
-
-    filepath = dbworkspacedir + s_config.get_key( "/config/session" ) + ".db" 
-
-#####################################################################
-
-def sql_execute( sql ) :
-    #s_log.write( sql )
-    cur = db_con.cursor( )
-    cur.execute( sql )
-    db_con.commit( )
-
-def sql_execute_parameters( sql , params_tuple ) :
-
-    cur = db_con.cursor( )
-    cur.execute( sql , params_tuple )
-    db_con.commit( )
-
-def sql_execute_fetchall( sql ) :
-    cur = db_con.cursor( )
-    cur.execute( sql )
-    rows = cur.fetchall( )
-    return( rows )
-
-def sql_execute_fetchone( sql ) :
-    cur = db_con.cursor( )
-    cur.execute( sql )
-    row = cur.fetchone( )
-    if( not row ) : return( False )
-    return( row )
-
 def table_readall( t , extra = "" ) :
     sql = "SELECT * FROM " + t + " " + extra
-    rows = sql_execute_fetchall( sql )
+    rows = sql_execute_fetch( sql ,fetch_all=True)
     return( rows )
 
 def table_truncate( t , extra = "" ) :
@@ -252,7 +190,7 @@ def table_truncate( t , extra = "" ) :
 
 def table_rowcount( t , extra = "") :
     sql = "SELECT COUNT(*) as count FROM " + t + " " + extra
-    row = sql_execute_fetchone( sql )
+    row = sql_execute_fetch( sql )
     return( row[ "count" ] )
 
 def tablerow_exists( t , extra = "" ) :
@@ -260,7 +198,6 @@ def tablerow_exists( t , extra = "" ) :
     if(row_count>0): return(True)
     return(False)
 
-
 #####################################################################
 
 def init_schema( ) :
@@ -311,7 +248,7 @@ def sys_create( sn , sv_in ) :
 
     sql = "INSERT INTO sys( sn , sv ) VALUES ( ? , ? )"
     data = ( sn , sv )
-    sql_execute_parameters( sql , data )
+    sql_execute( sql , data )
     return( True )
 
 def sys_count( ) :
@@ -321,7 +258,7 @@ def sys_count( ) :
 def sys_read( sn ) :
 
     sql = "SELECT * FROM sys where sn='" + sn + "' limit 1"
-    row = sql_execute_fetchone( sql )
+    row = sql_execute_fetch( sql )
     if( not row ) : return( False )
     return( json.loads( row[ "sv" ] )  )
 
@@ -333,7 +270,7 @@ def sys_update( sn , sv_in ) :
     sv = s_util.json_encode( sv_in )
     sql = "UPDATE sys SET sv=? where sn=?"
     data = ( sv , sn )
-    sql_execute_parameters( sql , data )
+    sql_execute( sql , data )
 
 def sys_delete( sn ) :
 
@@ -357,7 +294,7 @@ def stacks_create( sv_data , sk = 0 ) :
     sql = "INSERT INTO stacks ( sid , sk,sv ) VALUES ( ? , ? , ? )"
     data = ( None , sk,sv )
 
-    sql_execute_parameters( sql , data )
+    sql_execute( sql , data )
     return( True )
 
 def stacks_count( sk = 0 ) :
@@ -369,7 +306,7 @@ def stacks_count( sk = 0 ) :
 def stacks_read( sk = 0 ) :
 
     sql = "SELECT * FROM stacks where sk=" + str( sk ) + " order by sid desc" 
-    rows = sql_execute_fetchall( sql )
+    rows = sql_execute_fetch( sql , fetch_all=True)
     return( rows )
 
 def stacks_readall( ) :
@@ -381,7 +318,7 @@ def stacks_update( sid , sk , sv_data ) :
     sv = s_util.json_encode( sv_data )
     sql = "UPDATE stacks SET sk=? , sv=? where sid=?"
     data = ( sk , sv , sid )
-    sql_execute_parameters( sql , data )
+    sql_execute( sql , data )
 
 def stacks_delete( sk = 0 ) :
     sql = "DELETE FROM stacks where sk=" + str( sk ) 
@@ -395,7 +332,7 @@ def stacks_deleteall( ) :
 def stacks_pop( sk = 0 ) :
 
     sql = "SELECT * FROM stacks where sk=" + str( sk ) + " order by sid desc limit 1" 
-    rows = sql_execute_fetchall( sql )
+    rows = sql_execute_fetch( sql ,fetch_all=True)
 
     if( len( rows ) != 1 ) :
         return( False )
@@ -417,7 +354,7 @@ def env_create( en , ev ) :
 
     sql = "INSERT INTO env ( eid , en , ev ) VALUES ( null , ? , ? )"
     data = ( en , ev )
-    sql_execute_parameters( sql , data )
+    sql_execute( sql , data )
     return(True)
 
 def env_count( ) :
@@ -427,7 +364,7 @@ def env_count( ) :
 def env_read( en ) :
 
     sql = "SELECT * FROM env where en='" + en + "' limit 1"
-    row = sql_execute_fetchone( sql )
+    row = sql_execute_fetch( sql )
     return( row )
 
 def env_readall( ) :
@@ -437,7 +374,7 @@ def env_readall( ) :
 def env_update( en , ev ) :
     sql = "UPDATE env SET ev=? where en=?"
     data = ( ev , en )
-    sql_execute_parameters( sql , data )
+    sql_execute( sql , data )
 
 def env_delete( en ) :
 
@@ -459,7 +396,7 @@ def meta_create( mn , mv_in ) :
 
     sql = "INSERT INTO meta ( mn , mv ) VALUES ( ? , ? )"
     data = ( mn , mv )
-    sql_execute_parameters( sql , data )
+    sql_execute( sql , data )
     return(True)
 
 def meta_count( ) :
@@ -470,7 +407,7 @@ def meta_count( ) :
 def meta_read( mn ) :
 
     sql = "SELECT * FROM meta where mn='" + mn + "' limit 1"
-    row = sql_execute_fetchone( sql )
+    row = sql_execute_fetch( sql )
     if( not row ) : return( False )
     return( json.loads( row[ "mv" ] )  )
 
@@ -482,7 +419,7 @@ def meta_update( mn , mv_in ) :
     mv = s_util.json_encode( mv_in )
     sql = "UPDATE meta SET mv=? where mn=?"
     data = ( mv , mn )
-    sql_execute_parameters( sql , data )
+    sql_execute( sql , data )
 
 def meta_delete( mn ) :
 
@@ -507,7 +444,7 @@ def args_create( av ) :
 
     sql = "INSERT INTO args ( aid , av ) VALUES ( ? , ? )"
     data = ( None , av )
-    sql_execute_parameters( sql , data )
+    sql_execute( sql , data )
     return( True )
 
 def args_count( ) :
@@ -517,7 +454,7 @@ def args_count( ) :
 def args_read( aid ) :
 
     sql = "SELECT * FROM args where aid=" + aid + " limit 1"
-    row = sql_execute_fetchone( sql )
+    row = sql_execute_fetch( sql )
     return( row )
 
 def args_readall( ) :
@@ -527,7 +464,7 @@ def args_readall( ) :
 def args_update( aid , av ) :
     sql = "UPDATE args SET av=? where aid=?"
     data = ( av , aid )
-    sql_execute_parameters( sql , data )
+    sql_execute( sql , data )
 
 def args_delete( aid ) :
 
@@ -544,7 +481,7 @@ def args_deleteall( ) :
 def stdio_create( sk , sv ) :
     sql = "INSERT INTO stdio ( sid , sk , sv ) VALUES ( null , ? , ? )"
     data = ( sk , sv )
-    sql_execute_parameters( sql , data )
+    sql_execute( sql , data )
     return( True )
 
 def stdio_count( sk ) :
@@ -553,7 +490,7 @@ def stdio_count( sk ) :
 
 def stdio_read( sk ) :
     sql = "SELECT * FROM stdio where sk=" + str( sk ) + " order by sid asc" 
-    rows = sql_execute_fetchall( sql )
+    rows = sql_execute_fetch( sql ,fetch_all=True)
     return( rows )
 
 def stdio_readformatted( sk ) :
@@ -571,7 +508,7 @@ def stdio_readall( ) :
 def stdio_update( sid , sk , sv ) :
     sql = "UPDATE stdio SET sk=? , sv=? where sid=?"
     data = ( sk , sv , sid )
-    sql_execute_parameters( sql , data )
+    sql_execute( sql , data )
 
 def stdio_delete( sk = 0 ) :
 
@@ -622,7 +559,7 @@ def files_create( fp ) :
     sql = "INSERT INTO files ( fp , fc , fs , fh ) VALUES (?, ?, ?, ?)"
     data_tuple = ( fp , fc , fs , fh )
 
-    sql_execute_parameters( sql , data_tuple )
+    sql_execute( sql , data_tuple )
 
     return( True )
 
@@ -633,7 +570,7 @@ def files_count( ) :
 def files_read( fp ) :
 
     sql =  "SELECT * FROM files where fp='" + fp + "' limit 1" 
-    row = sql_execute_fetchone( sql )
+    row = sql_execute_fetch( sql )
     return( row )
 
 def files_readall( ) :
@@ -667,7 +604,7 @@ def files_dict2json( fp , fdict ) :
 
     sql = "INSERT INTO files ( fp , fc , fs , fh ) VALUES (?, ?, ?, ?)"
     data_tuple = ( fp , fc , fs , fh )
-    sql_execute_parameters( sql , data_tuple )
+    sql_execute( sql , data_tuple )
 
     return( True )
 
@@ -682,61 +619,13 @@ def files_write( fp ) :
     with open( fp , "w" , 1 ) as f :
         f.write( files_getcontent( fp ) )
 
-
-########################
-'''
-def files_defmeta_set( data ) :
-
-    files_delete( "./local_defmeta_5800b137d.json" )
-
-    flag = files_dict2json( "./local_defmeta_5800b137d.json" , data )
-    if not flag :
-        s_log.write( "False files_defmeta_set" )
-        return( False )
-
-    return( True )
-
-def files_defmeta_get( ) :
-    f = files_read( "./local_defmeta_5800b137d.json" )
-    if not f :
-        s_log.write( "False files_defmeta_set files_read" )
-        return( False )
-    d = json.loads( f[ "fc" ] )
-    return( d )
-
-def files_defmeta_write( ) :
-    files_write( "./local_defmeta_5800b137d.json" )
-########################
-def files_defdata_set( data ) :
-
-    files_delete( "./local_defdata_5800b137d.json" )
-
-    flag = files_dict2json( "./local_defdata_5800b137d.json" , data )
-    if not flag :
-        s_log.write( "False files_defdata_set" )
-        return( False )
-
-    return( True )
-
-def files_defdata_get( ) :
-    f = files_read( "./local_defdata_5800b137d.json" )
-    if not f :
-        s_log.write( "False files_defdata_get files_read" )
-        return( False )
-    d = json.loads( f[ "fc" ] )
-    return( d )
-
-def files_defdata_write( ) :
-    files_write( "./local_defdata_5800b137d.json" )
-'''
-
 ####################################################################
 
 def templates_create( tp , tk , tv ) :
     if( s_util.pathnotallowed( tp ) ) : return( False )
     sql = "INSERT INTO templates ( tp,tk,tv) VALUES ( ? , ? , ? )"
     data = ( tp , tk , tv )
-    sql_execute_parameters( sql , data )
+    sql_execute( sql , data )
     return(True)
 
 def templates_count( ) :
@@ -745,7 +634,7 @@ def templates_count( ) :
 
 def templates_read( tp ) :
     sql = "SELECT * FROM templates where tp='" + tp + "' order by tid asc" 
-    rows = sql_execute_fetchall( sql )
+    rows = sql_execute_fetch( sql ,fetch_all=True)
     return( rows ) 
 
 def templates_readall( ) :
@@ -755,7 +644,7 @@ def templates_readall( ) :
 def templates_update( tp , tk , tv ) :
     sql = "UPDATE templates SET tk=? , tv=? where tp=?"
     data = ( tk , tv , tp )
-    sql_execute_parameters( sql , data )
+    sql_execute( sql , data )
 
 def templates_delete( tp ) :
 
