@@ -24,6 +24,7 @@ import base64
 import shutil
 import gzip
 import inspect
+import glob
 
 import threading
 
@@ -79,6 +80,9 @@ def json_load( fn ) :
         j = json.load( f )
     return( j )
 
+def json_loads( str ) :
+    return( json.loads( str ) )
+
 #####################################################################
 
 # FIXME TODO aaarrggghhh!!!
@@ -186,7 +190,7 @@ def uptime_lap( ) :
 
 
 def printexit( msg ) :
-    print( "PREXIT: " + msg )
+    print( "PREXIT: " + str(msg) )
     sys.exit( )
 
 
@@ -386,27 +390,40 @@ def parent_path( ) :
 
 ################
 
+def environ_getall( ) :
+    return( os.environ )
+
+def environ_get( k ) :
+    if k in os.environ :
+        return( os.environ[k])
+    return(None)
+
 def container_appenvstatic_get( ) :
     ENV_STATIC = { }
     if "_CONTAINER_LOCAL_APPENVSTATIC" in os.environ :
         ENV_STATIC = dict( urllib.parse.parse_qsl( os.environ[ "_CONTAINER_LOCAL_APPENVSTATIC" ] ) )
     return( ENV_STATIC )
-    
+   
+
 
 def datetime_iso( ) :
     return( datetime.now( datetime.now( ).astimezone( ).tzinfo ).isoformat( ) )
 
 def time_now( ) :
-    return(time.time())
+    return( time.time( ) )
+
+def time_now_str( ) :
+    return( str( round( time_now( ) ) ) )
+
 def datetime_utcnow( ) :
-    return(datetime.utcnow( ) )
+    return( datetime.utcnow( ) )
 
 def url_parse( u ) :
     return(urllib.parse.urlparse(u))
 
 
 def sleep( t = 1 ) :
-    time.sleep(t) 
+    time.sleep( t ) 
 
 
 def datetime_now_db( td = 0 ) :
@@ -441,14 +458,36 @@ def file_getcontent( fn , scp ) :
 
     return( contents )
 
+def file_exists( fp ) :
+    return( os.path.isfile(fp) )
+
+def file_ctime( fp ) :
+    if(not file_exists(fp)): return(False)
+    return( os.path.getctime( fp ) )
+
+def file_changed( fp , ctime ) :
+    if(not file_exists(fp)): return(False)
+    return( file_ctime(fp)!=ctime)
+
 
 def path_stem( p ) :
     fn = Path( p ).stem
     return( fn )
 
+
+def sys_path_append_fp( fp ) :
+    if( not file_exists(fp)): return(False)
+    sys.path.append( os.path.dirname( fp ) )
+    return(True)
+
 ################
 
 def thread_get_id( ) :
     return( threading.get_ident( ) ) 
    
  
+##################
+
+
+def glob_files( dp ) :
+    return( glob.glob( dp ) )
