@@ -141,14 +141,13 @@ def server( runner , debug_errorprexit = False ) :
 
 runner_ctime = 0
 # Required to make module name scope available in function for importlib
-_sapi_runner = None
+_sapi_runner_omnibus = None
 def sapirunner_reloadifchanged( path_runner ) :
     global runner_ctime
-    #global _sapi_runner
     try :
         if( s_util.file_changed( path_runner , runner_ctime ) ) :
             runner_ctime = s_util.file_ctime( path_runner )
-            importlib.reload( _sapi_runner )
+            importlib.reload( _sapi_runner_omnibus )
             s_log.write( "path_runner RELOAD" , consoleprint = True )
             s_util.sleep( 3 )
 
@@ -161,9 +160,9 @@ def sapirunner_reloadifchanged( path_runner ) :
 
 
 def runner_omnibus( path_runner ) :
-    
+
     # Required to make module name scope available in function for importlib
-    global _sapi_runner
+    global _sapi_runner_omnibus
 
     s_log.write( "RUNNER_OMNIBUS START " + path_runner )
 
@@ -171,7 +170,7 @@ def runner_omnibus( path_runner ) :
         s_log.write( "ERROR NOT FOUND " + path_runner , consoleprint = True )
         prexit( "ERR" )
 
-    import _sapi_runner
+    import _sapi_runner_omnibus
 
     global runner_ctime
     runner_ctime = s_util.file_ctime( path_runner )
@@ -204,7 +203,7 @@ def runner_omnibus( path_runner ) :
 
         #####################################################
 
-        runner_exitcode = _sapi_runner._entrypoint( )
+        runner_exitcode = _sapi_runner_omnibus._entrypoint( )
         s_log.write( "runner_exitcode " + str(runner_exitcode) , consoleprint = True )
 
         #####################################################
